@@ -29,7 +29,7 @@
 #include "gnome-mud.h"
 
 static char const rcsid[] =
-    "$Id: data.c,v 1.16 2003/04/07 14:02:50 lobbin Exp $";
+    "$Id: data.c,v 1.20 2003/12/12 19:44:31 jordim Exp $";
 
 struct own_data {
 	GtkWidget		*button_delete,  
@@ -78,11 +78,11 @@ static gchar check_str (gchar *str)
 static gint find_data (GList *list, gchar *text)
 {
 	GList *entry;
-    gint i = 0;
+	gint i = 0;
 
 	for (entry = g_list_first(list); entry != NULL; entry = g_list_next(entry), i++)
 	{
-		if (!g_ascii_strncasecmp(((gchar **) entry->data)[0], text, strlen(text)))
+		if (!g_ascii_strncasecmp(((gchar **) entry->data)[0], text, strlen(((gchar **) entry->data)[0])))
 		{
 			return i;
 		}
@@ -171,7 +171,8 @@ static void data_sync_gconf(DDATA *data)
 	GSList *list = NULL, *elist;
 	GList  *entry;
 	gchar  *ldata;
-	gchar  *key = g_strdup_printf("/apps/gnome-mud/profiles/%s/%s", data->pd->name, data->file_name);
+	gchar  *pname = gconf_escape_key(data->pd->name, -1);
+	gchar  *key = g_strdup_printf("/apps/gnome-mud/profiles/%s/%s", pname, data->file_name);
 
 	for (entry = g_list_first(DATA_LIST(data)); entry != NULL; entry = g_list_next(entry))
 	{
@@ -189,6 +190,7 @@ static void data_sync_gconf(DDATA *data)
 
 	g_slist_free(list);
 	g_free(key);
+	g_free(pname);
 }
 
 static void data_delete_entry(DDATA *data, const gchar *entry, GtkTreeSelection *selection)
@@ -356,7 +358,7 @@ void window_data (PROFILE_DATA *profile, gint z)
 			break;
 			
 		default:
-	   		g_warning(_("window_data: trying to access to undefined data range: %d"), z);
+	   		g_warning(_("%s: trying to access to undefined data range: %d"), "window_data", z);
 			return;
     }
 
@@ -368,7 +370,7 @@ void window_data (PROFILE_DATA *profile, gint z)
     data->textname  = gtk_entry_new ();
     data->textvalue = gtk_entry_new ();
   
-    gtk_window_set_title (GTK_WINDOW (data->window), _("GNOME-Mud Configuration Centre"));
+    gtk_window_set_title (GTK_WINDOW (data->window), _("GNOME-Mud Configuration Center"));
     gtk_widget_set_usize (data->window,450,320);
 
 	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
