@@ -1,5 +1,5 @@
 /* GNOME-Mud - A simple Mud CLient
- * Copyright (C) 1998-2002 Robin Ericsson <lobbin@localhost.nu>
+ * Copyright (C) 1998-2005 Robin Ericsson <lobbin@localhost.nu>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,10 @@
 #endif
 
 #include "gnome-mud.h"
+#include "directions.h"
 
 static char const rcsid[] = 
-	"$Id: init.c,v 1.101 2004/02/11 12:58:25 jordim Exp $";
+	"$Id: init.c,v 1.105 2005/05/10 14:14:05 jordim Exp $";
 
 extern gchar        *host;
 extern gchar        *port;
@@ -285,7 +286,10 @@ static void window_menu_help_about (GtkWidget *widget, gpointer data)
 			    FALSE, FALSE, 0);
 
 	gtk_box_pack_start(GTK_BOX (GTK_DIALOG (about)->vbox), hbox, TRUE, TRUE, 0);
-	gtk_widget_show(hbox);
+	gtk_widget_show_all (hbox);
+
+	g_signal_connect(G_OBJECT(about), "destroy",
+			 G_CALLBACK(gtk_widget_destroyed), &about);
 
 	gtk_widget_show (about);
   }
@@ -319,6 +323,7 @@ static void text_entry_activate (GtkWidget *text_entry, gpointer data)
 	cd = connections[gtk_notebook_get_current_page(GTK_NOTEBOOK (main_notebook))];
 
 	EntryCurr = g_list_last (EntryHistory);
+	EntryCurr = NULL;
 
 	if (entry_text[0] == '\0') 
 	{
@@ -372,62 +377,62 @@ static int text_entry_key_press_cb (GtkEntry *text_entry, GdkEventKey *event, gp
 	if ( event->state & GDK_CONTROL_MASK ) { }
 	else
 	{
-		if (!prefs.DisableKeys)
+		if (!prefs.DisableKeys && cd->profile->directions)
 		{
 			switch ( event->keyval )
 			{
 				case GDK_KP_1:
-					text_entry_send_command(cd, "sw", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_SOUTHWEST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_2:
-					text_entry_send_command(cd, "s", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_SOUTH), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_3:
-					text_entry_send_command(cd, "se", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_SOUTHEAST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_4:
-					text_entry_send_command(cd, "w", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_WEST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_5:
-					text_entry_send_command(cd, "look", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_LOOK), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_6:
-					text_entry_send_command(cd, "e", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_EAST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_7:
-					text_entry_send_command(cd, "nw", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_NORTHWEST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_8:
-					text_entry_send_command(cd, "n", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_NORTH), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_9:
-					text_entry_send_command(cd, "ne", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_NORTHEAST), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_Add:
-					text_entry_send_command(cd, "d", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_DOWN), text_entry);
 					return TRUE;
 					break;
 
 				case GDK_KP_Subtract:
-					text_entry_send_command(cd, "u", text_entry);
+					text_entry_send_command(cd, (gchar*) g_slist_nth_data(cd->profile->directions, DIRECTION_UP), text_entry);
 					return TRUE;
 					break;
 			}
@@ -518,6 +523,7 @@ CONNECTION_DATA *create_connection_data(gint notebook)
 #endif /* ENABLE_MCCP */
 	c->telnet_state = 0;
 	c->telnet_subneg = 0;
+	c->naws = FALSE;
 	c->notebook = notebook;
 	c->profile = profiledata_find("Default");
 	c->window = vte_terminal_new();
@@ -531,12 +537,16 @@ CONNECTION_DATA *create_connection_data(gint notebook)
 	
 	GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(c->window), GTK_CAN_FOCUS);
 
-	gtk_signal_connect(GTK_OBJECT(c->window), "focus-in-event", GTK_SIGNAL_FUNC(grab_focus_cb), NULL);
+	g_signal_connect(G_OBJECT(c->window), "focus-in-event", G_CALLBACK(grab_focus_cb), NULL);
 	connections[notebook] = c;
 
 	c->vscrollbar = gtk_vscrollbar_new(NULL);
 	gtk_range_set_adjustment(GTK_RANGE(c->vscrollbar), VTE_TERMINAL(c->window)->adjustment);
 
+	/* Signals to be able to correct NAWS */
+	g_signal_connect(G_OBJECT(c->window), "char-size-changed", G_CALLBACK(vte_char_size_changed_cb), c);
+	g_signal_connect_after(G_OBJECT(c->window), "size-allocate", G_CALLBACK(vte_resize_window_cb), c);
+
 	return c;
 }
 
